<?php

namespace Ems\Controllers;

use Ems\Services\FeriasService;
use Ems\Util\ExpectedException;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class FeriasController {
    
    public function __construct(FeriasService $feriasService) {
        $this->feriasService = $feriasService;
    }
    
    public function getProgramacaoFerias(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            $estrutgeren        = $row['NRESTRUTURAM'];
            $nrperiodoapuracao  = $row['NRPERIODOAPURACAO'];
            
            $programacaoFerias = $this->feriasService->getProgramacaoFerias($nrperiodoapuracao, null, $estrutgeren);

            $response->addDataSet(new DataSet('programacaoFerias', $programacaoFerias));
        } catch(\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }
    
    
    public function setProgramacaoFerias(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();

            $rows = !empty($row['ROWS']) ? $row['ROWS'][0] : null;
            $cdoperador = $row['CDOPERADOR'];
            $success = $this->feriasService->setMultiplasProgramacaoFerias($rows, $cdoperador);

            $response->addDataSet(new DataSet('setProgramacaoFerias', array($success)));
        } catch (ExpectedException $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
}