<?php

namespace Util;

use Doctrine\ORM\EntityManager;

class QueryUtils {
    
    protected const SQL_UPDATE_STATEMENT = "UPDATE @TABLE_NAME@ SET @COLUMN_VALUES@ WHERE @WHERE_CONDITION@";
    
    /**
     * Rotina que monta uma operação UPDATE a partir de parâmetros passados.
     * 
     * @param string $tableName         | Nome da tabela.
     * @param Array  $columnsValues     | Array com os novos valores. Formato ['COLUNA'] => VALOR.
     * @param string $whereClause       | String com a cláusula WHERE, não contendo a palavra-chave 'WHERE'.
     * @param bool   $includeNullValues | Flag que determina ser valores NULL serão incluídos na query. Default: True
     * 
     * @return string $finalQuery       | Retorna query SQL em string.
     * 
     */
     
    public static function buildUpdateStament(
        string $tableName,
        Array  $columnsValues,
        string $whereClause,
        bool   $includeNullValues = true
    ) {
        $sqlColumnsSetClause = '';
        foreach($columnsValues as $column => $value) {
            if ($value != null || $includeNullValues) {
                // if ($includeNullValues) {
                //     $value = 'null';
                // }
                $isValueString = gettype($value) == 'string';
                $stringFlag = $isValueString ? "'" : "";
                
                $sqlColumnsSetClause .= " $column = " . $stringFlag . (is_null($value) ? 'null' : $value) . $stringFlag . ", ";
            }
        }
        
        if (empty($sqlColumnsSetClause)) {
            return false;
        }
        
        // Remove último espaço e vírgula
        $sqlColumnsSetClause = substr($sqlColumnsSetClause, 0, -2);
        
        // Monta a query com a estrutura do update
        $finalQuery = strtr(self::SQL_UPDATE_STATEMENT, array(
            '@TABLE_NAME@' => $tableName,
            '@COLUMN_VALUES@' => $sqlColumnsSetClause,
            '@WHERE_CONDITION@' => $whereClause
        ));
        
        
        return $finalQuery;
    }
}